@@ -50,7 +50,7 @@ server <- function(input, output, session) {
     output$itemTime <- renderText({
         printDebug("itemTime", 3)
         invalidateLater(200, session)
-        if(.MCE[[sessionName]]$person$terminated_sucessfully)
+        if(.MCE[[sessionName]]$person$terminated_sucessfully || .MCE[[sessionName]]$STOP)
             return(NULL)
         item <- .MCE[[sessionName]]$item
         delta_msg <- .MCE[[sessionName]]$shinyGUI$timemsg
@@ -60,7 +60,12 @@ server <- function(input, output, session) {
             if(delta_time < .3 && is.na(.MCE[[sessionName]]$person$raw_responses[item]) && 
                .MCE[[sessionName]]$test@has_answers[item])
                 .MCE[[sessionName]]$person$responses[item] <- 0L
-            if(delta_time < 0) delta_time <- 0
+            if(delta_time < 0){
+                delta_time <- 0
+                if(is.na(.MCE[[sessionName]]$person$raw_responses[item]) && 
+                   .MCE[[sessionName]]$test@has_answers[item])
+                    .MCE[[sessionName]]$person$responses[item] <- 0L
+            }
             return(paste0(.MCE[[sessionName]]$shinyGUI$itemtimer,
                           formatTime(as.integer(delta_time), delta_msg)))
         } else return(NULL)
@@ -254,7 +259,9 @@ server <- function(input, output, session) {
                     .MCE[[sessionName]]$person$Update.info_mats(design=.MCE[[sessionName]]$design, test=.MCE[[sessionName]]$test)
                     if(.MCE[[sessionName]]$shinyGUI$temp_file != '')
                         saveRDS(.MCE[[sessionName]]$person, .MCE[[sessionName]]$shinyGUI$temp_file)
-                    .MCE[[sessionName]]$design <- Update.stop_now(.MCE[[sessionName]]$design, person=.MCE[[sessionName]]$person)
+                    .MCE[[sessionName]]$design <- Update.stop_now(.MCE[[sessionName]]$design, 
+                                                                  person=.MCE[[sessionName]]$person,
+                                                                  test=.MCE[[sessionName]]$test)
                 } else {
                     printDebug("No observed response")
                     if(!item_time_valid || (.MCE[[sessionName]]$shinyGUI$forced_choice && 
@@ -282,13 +289,17 @@ server <- function(input, output, session) {
                         .MCE[[sessionName]]$person$item_time[pick] <- min(diff_item_time, 
                                                                           .MCE[[sessionName]]$shinyGUI$timer[pick])
                         .MCE[[sessionName]]$start_time <- NULL
+                        if(.MCE[[sessionName]]$test@has_answers[pick])
+                            .MCE[[sessionName]]$person$responses[pick] <- 0L
                         #update Thetas (same as above)
                         .MCE[[sessionName]]$design@Update.thetas(design=.MCE[[sessionName]]$design, 
                                                                  person=.MCE[[sessionName]]$person, test=.MCE[[sessionName]]$test)
                         .MCE[[sessionName]]$person$Update.info_mats(design=.MCE[[sessionName]]$design, test=.MCE[[sessionName]]$test)
                         if(.MCE[[sessionName]]$shinyGUI$temp_file != '')
                             saveRDS(.MCE[[sessionName]]$person, .MCE[[sessionName]]$shinyGUI$temp_file)
-                        .MCE[[sessionName]]$design <- Update.stop_now(.MCE[[sessionName]]$design, person=.MCE[[sessionName]]$person)
+                        .MCE[[sessionName]]$design <- Update.stop_now(.MCE[[sessionName]]$design, 
+                                                                      person=.MCE[[sessionName]]$person,
+                                                                      test=.MCE[[sessionName]]$test)
                         .MCE[[sessionName]]$person$valid_item[pick] <- FALSE
                     }
                 }
